@@ -1,7 +1,7 @@
 # from recipes:::names0
 names0 <- function(num, prefix = "x") {
   if (num < 1) {
-    stop("`num` should be > 0", call. = FALSE)
+    rlang::abort("`num` should be > 0")
   }
   ind <- format(1:num)
   ind <- gsub(" ", "0", ind)
