@@ -1,35 +1,21 @@
-context("hat_values score tests")
-
 test_that("`score_apd_hat_values_numeric` fails when model has no pcs argument", {
-  expect_error(
-    score_apd_hat_values_numeric(mtcars, mtcars),
-    "The model must contain an XtX_inv argument.",
-    fixed = TRUE
+  expect_snapshot(error = TRUE,
+    score_apd_hat_values_numeric(mtcars, mtcars)
   )
 })
 
 test_that("`score` fails when predictors only contain factors", {
   model <- apd_hat_values(~., iris)
-  expect_error(
-    score(model, iris$Species),
-    "The class of `new_data`, 'factor', is not recognized.",
-    fixed = TRUE
+  expect_snapshot(error = TRUE,
+    score(model, iris$Species)
   )
 })
 
 test_that("`score` fails when predictors are vectors", {
   object <- iris
-  cls <- class(object)[1]
-  message <-
-    "`object` is not of a recognized type.
-     Only data.frame, matrix, recipe, and formula objects are allowed.
-     A {cls} was specified."
-  message <- glue::glue(message)
 
-  expect_error(
-    score(object),
-    message,
-    fixed = TRUE
+  expect_snapshot(error = TRUE,
+    score(object)
   )
 })
 
@@ -44,7 +30,7 @@ test_that("`score` calculated hat_values are correct", {
   actual_output <- actual_output$hat_values
 
   # Data frame method
-  expect_equivalent(
+  expect_equal(ignore_attr = TRUE,
     actual_output,
     expected
   )
